Index: shell/android/apk/src/org/chromium/mojo/shell/MojoShellActivity.java |
diff --git a/shell/android/apk/src/org/chromium/mojo/shell/MojoShellActivity.java b/shell/android/apk/src/org/chromium/mojo/shell/MojoShellActivity.java |
index 023b929d927024982d240e1583d04a0f6bc52387..a56c43de651efc3659823a18418bb9024ad8061b 100644 |
--- a/shell/android/apk/src/org/chromium/mojo/shell/MojoShellActivity.java |
+++ b/shell/android/apk/src/org/chromium/mojo/shell/MojoShellActivity.java |
@@ -32,10 +32,10 @@ public class MojoShellActivity extends Activity { |
// TODO(qsr): We should be passing application context here as required by |
// InitApplicationContext on the native side. Currently we can't, as PlatformViewportAndroid |
// relies on this being the activity context. |
- MojoMain.ensureInitialized(this, getParametersFromIntent(getIntent())); |
+ ShellMain.ensureInitialized(this, getParametersFromIntent(getIntent())); |
- // TODO(eseidel): MojoMain can fail, but we're ignoring the return. |
- MojoMain.start(); |
+ // TODO(eseidel): ShellMain can fail, but we're ignoring the return. |
+ ShellMain.start(); |
} |
private static String[] getParametersFromIntent(Intent intent) { |